
<p align="center">
  <img src="https://raw.githubusercontent.com/PySimpleGUI/PySimpleGUI/master/images/for_readme/Logo%20with%20text%20for%20GitHub%20Top.png" alt="Python GUIs for Humans">
  <h2 align="center">psgdemos - The PySimpleGUI Demos and Demo Browser</h2>
  <h2 align="center">An Official PySimpleGUI Application</h2>

</p>


![image](https://user-images.githubusercontent.com/46163555/154766381-82c9c1b6-00d3-45c1-a59f-113c8eba543e.png)






## Installation

### Old-school Straight Pip

pip install psgdemos

### pip via `python -m pip` the python recommended way

#### If `python` is your command

python -m pip install psgdemos

#### If `python3` is your command

python3 -m pip install psgdemos

## Usage

Open a command window and type:   

`psgdemos`   

This will launch the "Demo Browser", your gateway to over 300 PySimpleGUI Demo Programs.


## Create a Shortcut To This Program

If you're a Windows user, then use the [`psgshortcut` application](https://pypi.org/project/psgshortcut/) to make a shortcut to this program so that you can then put on your desktop or pin to your taskbar (or any  other use that stops the need to type `psgdemos` ever again).

To get `psgshortcut`, like all of the other `psg application` projects, pip install it.  (e.g. `pip install psgshortcut`)



To do this, follow these steps:

1. Open a command window (I promise, it's the last time you'll need to for this program)
2. Type - `where psgdemos`
3. Copy the line that `where psgdemos` gave you into the first input of the shortcut maker program
4. Run psgdemos by typing `psgdemos` in your command window
5. Right click and choose "File Location"
6. Copy the file location results, but change the extension from .py to .ico and paste into the Icon file input of the shortcut maker
7. Click "Create Shortcut"

This will create a shortcut in the same folder as the target file.  You can safely move this shortcut file to any place you want (like to your desktop).  Double-click the shortcut and your program should launch.

## Release Notes

1.10.0   8-May-2022
* **Numerous** updates to the demo programs. Have been holding some back to ensure PySimpleGUI 4.60.0 released first

1.9.0   26-Feb-2022
* Addition of Time Desktop Widget & updated several older Demo Programs

1.8.0   22-Feb-2022
* Continuing to "play catchup" with checking in Demo Program changes that were missed initially... many more to come...

1.7.0   18-Feb-2022
* Removed the "Edit Me" button. Use the right click menu to edit the Demo Browser
* Updated a number of the Demos - found that a bunch of changes have not been released... much more to come soon...
    
1.6.0   14-Feb-2022
* Addition of Demo_Fonts_Using_pyglet.py and OpenFlame.ttf

1.5.0   13-Feb-2022
* Addition of new Demo_Graph_Custom_Progress_Meter.py
* Updated the PIL Emoji Toolbar demo

1.4.0   3-Feb-2022
* Addition of new Demo_All_Elements_Simple.py

1.3.0   31-Jan-2022
* Made "Advanced Mode" on by default

1.2.1   31-Jan-2022
* Fixed the settings filename extension

1.2.0   31-Jan-2022
* Sync up the version numbers
* Updated the Bar Chart demo

1.1.1   31-Jan-2022
* Initial Release  


## License

Licensed under an LGPL3 License  
Copyright 2022

## This PySimpleGUI Application Was Designed and Written By

Mike from PySimpleGUI.org as part of the  

[**The PySimpleGUI Project**](http://www.PySimpleGUI.com)

The programs installed and the Demo Browser both reside in the PySimpleGUI Repo on GitHub.  The Demo Browser installed via PyPI is slightly different than the Demo Browser found in the PySimpleGUI Repo.  You can tell the difference by looking at the program's icon.  If it has the PySimpleGUI Emoji as the icon, then it's the pip installed `psgdemo` version.  If the icon is a light bulb, then you're running the version from the PySimpleGUI repo.



## Contributing

Like the PySimpleGUI project, this project is currently licensed under an open-source license, the project itself is structured like a proprietary product. Pull Requests are not accepted.

## Copyright

Copyright 2022 PySimpleGUI
